Pearmut Evaluation

- Error spans:
  - Click on the start of an error, then click on the end to mark an error span.
  - Click on an existing highlight to change error severity (minor/major) or remove it.
  Error severity:
  - Minor: Style, grammar, or word choice could be better.
  - Major: Meaning is significantly changed or is hard to understand.
  Tip: Mark the general area of the error (doesn't need to be exact). Use separate highlights for different errors. Use `[missing]` at the end of a sentence for omitted content.
- Score each translation using the slider based on meaning preservation and quality. Important: The relative order of scores matters; ensure better translations have higher scores than worse ones.

- 0: Nonsense: most information is lost.
- 33%: Broken: major gaps and narrative issues.
- 66%: Middling: minor issues with grammar or consistency.
- 100%: Perfect: meaning and grammar align completely with the source.

- Error types: After highlighting an error fragment, you will be asked to select the specific error type (main category and subcategory). If you are unsure about which errors fall under which categories, please consult the typology definitions.

Time: 0m
Show approximate alignment
Word-level selection